aboutsummaryrefslogtreecommitdiff
path: root/engines/lure
diff options
context:
space:
mode:
Diffstat (limited to 'engines/lure')
-rw-r--r--engines/lure/animseq.cpp3
-rw-r--r--engines/lure/animseq.h3
-rw-r--r--engines/lure/debugger.cpp5
-rw-r--r--engines/lure/debugger.h3
-rw-r--r--engines/lure/decode.cpp13
-rw-r--r--engines/lure/decode.h3
-rw-r--r--engines/lure/detection.cpp5
-rw-r--r--engines/lure/disk.cpp3
-rw-r--r--engines/lure/disk.h3
-rw-r--r--engines/lure/events.cpp3
-rw-r--r--engines/lure/events.h3
-rw-r--r--engines/lure/fights.cpp3
-rw-r--r--engines/lure/fights.h3
-rw-r--r--engines/lure/game.cpp3
-rw-r--r--engines/lure/game.h3
-rw-r--r--engines/lure/hotspots.cpp3
-rw-r--r--engines/lure/hotspots.h3
-rw-r--r--engines/lure/intro.cpp3
-rw-r--r--engines/lure/intro.h3
-rw-r--r--engines/lure/lure.cpp20
-rw-r--r--engines/lure/lure.h5
-rw-r--r--engines/lure/luredefs.h3
-rw-r--r--engines/lure/memory.cpp3
-rw-r--r--engines/lure/memory.h3
-rw-r--r--engines/lure/menu.cpp3
-rw-r--r--engines/lure/menu.h3
-rw-r--r--engines/lure/palette.cpp3
-rw-r--r--engines/lure/palette.h3
-rw-r--r--engines/lure/res.cpp5
-rw-r--r--engines/lure/res.h5
-rw-r--r--engines/lure/res_struct.cpp5
-rw-r--r--engines/lure/res_struct.h3
-rw-r--r--engines/lure/room.cpp3
-rw-r--r--engines/lure/room.h3
-rw-r--r--engines/lure/screen.cpp3
-rw-r--r--engines/lure/screen.h3
-rw-r--r--engines/lure/scripts.cpp6
-rw-r--r--engines/lure/scripts.h3
-rw-r--r--engines/lure/sound.cpp3
-rw-r--r--engines/lure/sound.h5
-rw-r--r--engines/lure/strings.cpp3
-rw-r--r--engines/lure/strings.h3
-rw-r--r--engines/lure/surface.cpp11
-rw-r--r--engines/lure/surface.h7
44 files changed, 27 insertions, 161 deletions
diff --git a/engines/lure/animseq.cpp b/engines/lure/animseq.cpp
index 9c18cb33aa..8037563677 100644
--- a/engines/lure/animseq.cpp
+++ b/engines/lure/animseq.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/animseq.h"
diff --git a/engines/lure/animseq.h b/engines/lure/animseq.h
index 3609837dba..fde1fab921 100644
--- a/engines/lure/animseq.h
+++ b/engines/lure/animseq.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_ANIMSEQ_H
diff --git a/engines/lure/debugger.cpp b/engines/lure/debugger.cpp
index fc2029c6c4..68410875f7 100644
--- a/engines/lure/debugger.cpp
+++ b/engines/lure/debugger.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "common/config-manager.h"
@@ -537,7 +534,7 @@ bool Debugger::cmd_showAnim(int argc, const char **argv) {
}
// Bottle object is used as a handy hotspot holder that doesn't have any
- // tick proc behaviour that we need to worry about
+ // tick proc behavior that we need to worry about
Hotspot *hotspot = res.activateHotspot(BOTTLE_HOTSPOT_ID);
hotspot->setLayer(0xfe);
hotspot->setSize(width, height);
diff --git a/engines/lure/debugger.h b/engines/lure/debugger.h
index dd1d8b5fc6..a4d4d689c4 100644
--- a/engines/lure/debugger.h
+++ b/engines/lure/debugger.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_DEBUGGER_H
diff --git a/engines/lure/decode.cpp b/engines/lure/decode.cpp
index 5ffdcf1884..59390e6e91 100644
--- a/engines/lure/decode.cpp
+++ b/engines/lure/decode.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/decode.h"
@@ -134,7 +131,7 @@ MemoryBlock *PictureDecoder::egaDecode(MemoryBlock *src, uint32 maxOutputSize) {
READ_BIT_DX
if (!bitFlag) {
- // Get the favourite color
+ // Get the favorite color
v = popTable[tableOffset];
} else {
@@ -146,7 +143,7 @@ MemoryBlock *PictureDecoder::egaDecode(MemoryBlock *src, uint32 maxOutputSize) {
READ_BIT_DX
if (bitFlag) {
- // We have no favourite. Could this be a repeat?
+ // We have no favorite. Could this be a repeat?
al = dx >> 11;
READ_BITS(5);
@@ -187,7 +184,7 @@ MemoryBlock *PictureDecoder::egaDecode(MemoryBlock *src, uint32 maxOutputSize) {
}
} else {
- // Fourth favourite
+ // Fourth favorite
v = popTable[tableOffset + 96];
}
@@ -196,10 +193,10 @@ MemoryBlock *PictureDecoder::egaDecode(MemoryBlock *src, uint32 maxOutputSize) {
READ_BIT_DX
if (bitFlag) {
- // Third favourite
+ // Third favorite
v = popTable[tableOffset + 64];
} else {
- // Second favourite
+ // Second favorite
v = popTable[tableOffset + 32];
}
}
diff --git a/engines/lure/decode.h b/engines/lure/decode.h
index 9cc594df64..93f617af7e 100644
--- a/engines/lure/decode.h
+++ b/engines/lure/decode.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_DECODE_H
diff --git a/engines/lure/detection.cpp b/engines/lure/detection.cpp
index dd2a702e2a..4d03148e31 100644
--- a/engines/lure/detection.cpp
+++ b/engines/lure/detection.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "base/plugins.h"
@@ -208,7 +205,7 @@ public:
LureMetaEngine() : AdvancedMetaEngine(detectionParams) {}
virtual const char *getName() const {
- return "Lure of the Temptress Engine";
+ return "Lure";
}
virtual const char *getOriginalCopyright() const {
diff --git a/engines/lure/disk.cpp b/engines/lure/disk.cpp
index f1838e3d67..9212508be0 100644
--- a/engines/lure/disk.cpp
+++ b/engines/lure/disk.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
diff --git a/engines/lure/disk.h b/engines/lure/disk.h
index 79aaf80bbc..1872fbd055 100644
--- a/engines/lure/disk.h
+++ b/engines/lure/disk.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_DISK_H
diff --git a/engines/lure/events.cpp b/engines/lure/events.cpp
index f56a57ca34..fe60b56658 100644
--- a/engines/lure/events.cpp
+++ b/engines/lure/events.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
diff --git a/engines/lure/events.h b/engines/lure/events.h
index f04072aa0f..dd3f82fe19 100644
--- a/engines/lure/events.h
+++ b/engines/lure/events.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_EVENTS_H
diff --git a/engines/lure/fights.cpp b/engines/lure/fights.cpp
index 983033281a..ab5d992bdb 100644
--- a/engines/lure/fights.cpp
+++ b/engines/lure/fights.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/fights.h"
diff --git a/engines/lure/fights.h b/engines/lure/fights.h
index 0aa44030d2..89f49d8c6d 100644
--- a/engines/lure/fights.h
+++ b/engines/lure/fights.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_FIGHT_H
diff --git a/engines/lure/game.cpp b/engines/lure/game.cpp
index 7e13cff032..9542c35785 100644
--- a/engines/lure/game.cpp
+++ b/engines/lure/game.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/game.h"
diff --git a/engines/lure/game.h b/engines/lure/game.h
index 123ac0dca7..42818e404b 100644
--- a/engines/lure/game.h
+++ b/engines/lure/game.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_GAME_H
diff --git a/engines/lure/hotspots.cpp b/engines/lure/hotspots.cpp
index 5644ef798c..97fbaa72ae 100644
--- a/engines/lure/hotspots.cpp
+++ b/engines/lure/hotspots.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/hotspots.h"
diff --git a/engines/lure/hotspots.h b/engines/lure/hotspots.h
index e9f5d56edd..a58a34456e 100644
--- a/engines/lure/hotspots.h
+++ b/engines/lure/hotspots.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_HOTSPOTS_H
diff --git a/engines/lure/intro.cpp b/engines/lure/intro.cpp
index e054408a49..ce330be7c4 100644
--- a/engines/lure/intro.cpp
+++ b/engines/lure/intro.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/lure.h"
diff --git a/engines/lure/intro.h b/engines/lure/intro.h
index f4713c562a..ad442f1564 100644
--- a/engines/lure/intro.h
+++ b/engines/lure/intro.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_INTRO_H
diff --git a/engines/lure/lure.h b/engines/lure/lure.h
index 52b785a09a..7a67c8b855 100644
--- a/engines/lure/lure.h
+++ b/engines/lure/lure.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_H
@@ -68,7 +65,7 @@ struct LureGameDescription;
class LureEngine : public Engine {
private:
- bool _initialised;
+ bool _initialized;
int _gameToLoad;
uint8 _saveVersion;
Disk *_disk;
diff --git a/engines/lure/luredefs.h b/engines/lure/luredefs.h
index 0ef7a73b7e..91fb650af3 100644
--- a/engines/lure/luredefs.h
+++ b/engines/lure/luredefs.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LUREDEFS_H
diff --git a/engines/lure/memory.cpp b/engines/lure/memory.cpp
index d3d5067cce..c5c28fa8bc 100644
--- a/engines/lure/memory.cpp
+++ b/engines/lure/memory.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/memory.h"
diff --git a/engines/lure/memory.h b/engines/lure/memory.h
index f51c4fc49e..05bf23a9ab 100644
--- a/engines/lure/memory.h
+++ b/engines/lure/memory.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_MEMORY_H
diff --git a/engines/lure/menu.cpp b/engines/lure/menu.cpp
index f9a78d8fc8..9919471c76 100644
--- a/engines/lure/menu.cpp
+++ b/engines/lure/menu.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/menu.h"
diff --git a/engines/lure/menu.h b/engines/lure/menu.h
index fcc6308375..b3016f0560 100644
--- a/engines/lure/menu.h
+++ b/engines/lure/menu.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_MENU_H
diff --git a/engines/lure/palette.cpp b/engines/lure/palette.cpp
index b08ca64dfb..3975561749 100644
--- a/engines/lure/palette.cpp
+++ b/engines/lure/palette.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/lure.h"
diff --git a/engines/lure/palette.h b/engines/lure/palette.h
index 9420079346..2af1f55973 100644
--- a/engines/lure/palette.h
+++ b/engines/lure/palette.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_PALETTE_H
diff --git a/engines/lure/res.cpp b/engines/lure/res.cpp
index 01b0bd0d4a..fbf9f33b87 100644
--- a/engines/lure/res.cpp
+++ b/engines/lure/res.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/res.h"
@@ -348,7 +345,7 @@ void Resources::reloadData() {
}
delete mb;
- // Initialise delay list
+ // Initialize delay list
_delayList.clear(true);
// Load miscellaneous data
diff --git a/engines/lure/res.h b/engines/lure/res.h
index cd6fcde201..a0a908f53d 100644
--- a/engines/lure/res.h
+++ b/engines/lure/res.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_RES_H
@@ -117,7 +114,7 @@ public:
MemoryBlock *messagesData() { return _messagesData; }
uint16 getHotspotScript(uint16 index);
HotspotList &activeHotspots() { return _activeHotspots; }
- uint16 random() { return _rnd.getRandomNumber(65536) & 0xffff; }
+ uint16 getRandom() { return _rnd.getRandomNumber(0xffff); }
HotspotData *getHotspot(uint16 hotspotId);
Hotspot *getActiveHotspot(uint16 hotspotId);
HotspotOverrideData *getHotspotOverride(uint16 hotspotId);
diff --git a/engines/lure/res_struct.cpp b/engines/lure/res_struct.cpp
index 39beb2729e..222f55b5dc 100644
--- a/engines/lure/res_struct.cpp
+++ b/engines/lure/res_struct.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/disk.h"
@@ -418,7 +415,7 @@ HotspotData::HotspotData(HotspotResource *rec) {
flags2 = READ_LE_UINT16(&rec->flags2);
headerFlags = READ_LE_UINT16(&rec->hdrFlags);
- // Initialise runtime fields
+ // Initialize runtime fields
actionCtr = 0;
blockedState = BS_NONE;
blockedFlag = false;
diff --git a/engines/lure/res_struct.h b/engines/lure/res_struct.h
index 58ee3f4c02..49b6ef78ba 100644
--- a/engines/lure/res_struct.h
+++ b/engines/lure/res_struct.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_RESSTRUCT_H
diff --git a/engines/lure/room.cpp b/engines/lure/room.cpp
index 4cefe1fabb..2cb871d73f 100644
--- a/engines/lure/room.cpp
+++ b/engines/lure/room.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/room.h"
diff --git a/engines/lure/room.h b/engines/lure/room.h
index f24136ac42..deafa28a66 100644
--- a/engines/lure/room.h
+++ b/engines/lure/room.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_ROOM_H
diff --git a/engines/lure/screen.cpp b/engines/lure/screen.cpp
index e02f492ef2..4eb6fd46a3 100644
--- a/engines/lure/screen.cpp
+++ b/engines/lure/screen.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/screen.h"
diff --git a/engines/lure/screen.h b/engines/lure/screen.h
index 94bbab932e..2a2fa6b2f2 100644
--- a/engines/lure/screen.h
+++ b/engines/lure/screen.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_SCREEN_H
diff --git a/engines/lure/scripts.cpp b/engines/lure/scripts.cpp
index 20cbd328ce..22656dd3fe 100644
--- a/engines/lure/scripts.cpp
+++ b/engines/lure/scripts.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/animseq.h"
@@ -34,7 +31,6 @@
#include "lure/sound.h"
#include "common/stack.h"
#include "common/endian.h"
-#include "common/EventRecorder.h"
namespace Lure {
@@ -1131,7 +1127,7 @@ uint16 Script::execute(uint16 startOffset) {
break;
case S_OPCODE_RANDOM:
- param = r.random() >> 8; // make number between 0 to 255
+ param = r.getRandom() >> 8; // make number between 0 to 255
break;
case S_OPCODE_END:
diff --git a/engines/lure/scripts.h b/engines/lure/scripts.h
index b5b6140872..7bc8f8c950 100644
--- a/engines/lure/scripts.h
+++ b/engines/lure/scripts.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_SCRIPTS_H
diff --git a/engines/lure/sound.cpp b/engines/lure/sound.cpp
index da9e136ec3..cf28e0bb74 100644
--- a/engines/lure/sound.cpp
+++ b/engines/lure/sound.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/sound.h"
diff --git a/engines/lure/sound.h b/engines/lure/sound.h
index 7a894d814d..9fa9a91260 100644
--- a/engines/lure/sound.h
+++ b/engines/lure/sound.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_SOUND_H
@@ -156,7 +153,7 @@ public:
uint sfxVolume() const { return _sfxVolume; }
// The following methods implement the external sound player module
- void musicInterface_Initialise();
+ void musicInterface_Initialize();
void musicInterface_Play(uint8 soundNumber, uint8 channelNumber, uint8 numChannels = 4);
void musicInterface_Stop(uint8 soundNumber);
bool musicInterface_CheckPlaying(uint8 soundNumber);
diff --git a/engines/lure/strings.cpp b/engines/lure/strings.cpp
index 7c3f358080..0c9f4b5352 100644
--- a/engines/lure/strings.cpp
+++ b/engines/lure/strings.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/strings.h"
diff --git a/engines/lure/strings.h b/engines/lure/strings.h
index 8dbca70813..e32921ddb6 100644
--- a/engines/lure/strings.h
+++ b/engines/lure/strings.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_STRINGS_H
diff --git a/engines/lure/surface.h b/engines/lure/surface.h
index 9a677cf749..d56e37632b 100644
--- a/engines/lure/surface.h
+++ b/engines/lure/surface.h
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#ifndef LURE_SURFACE_H
@@ -52,8 +49,8 @@ public:
static void getDialogBounds(Common::Point &size, int charWidth, int numLines,
bool squashedLines = true);
- static void initialise();
- static void deinitialise();
+ static void initialize();
+ static void deinitialize();
uint16 width() { return _width; }
uint16 height() { return _height; }
diff --git a/engines/lure/lure.cpp b/engines/lure/lure.cpp
index b0968c1956..3217cf039d 100644
--- a/engines/lure/lure.cpp
+++ b/engines/lure/lure.cpp
@@ -18,16 +18,12 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "common/config-manager.h"
#include "common/debug-channels.h"
#include "common/system.h"
#include "common/savefile.h"
-#include "common/EventRecorder.h"
#include "engines/util.h"
@@ -42,8 +38,8 @@ namespace Lure {
static LureEngine *int_engine = NULL;
-LureEngine::LureEngine(OSystem *system, const LureGameDescription *gameDesc): Engine(system), _gameDescription(gameDesc) {
- g_eventRec.registerRandomSource(_rnd, "lure");
+LureEngine::LureEngine(OSystem *system, const LureGameDescription *gameDesc)
+ : Engine(system), _gameDescription(gameDesc), _rnd("lure") {
DebugMan.addDebugChannel(kLureDebugScripts, "scripts", "Scripts debugging");
DebugMan.addDebugChannel(kLureDebugAnimations, "animations", "Animations debugging");
@@ -55,7 +51,7 @@ LureEngine::LureEngine(OSystem *system, const LureGameDescription *gameDesc): En
Common::Error LureEngine::init() {
int_engine = this;
- _initialised = false;
+ _initialized = false;
_saveLoadAllowed = false;
initGraphics(FULL_SCREEN_WIDTH, FULL_SCREEN_HEIGHT, false);
@@ -89,12 +85,12 @@ Common::Error LureEngine::init() {
_mouse = new Mouse();
_events = new Events();
_menu = new Menu();
- Surface::initialise();
+ Surface::initialize();
_room = new Room();
_fights = new FightsManager();
_gameToLoad = -1;
- _initialised = true;
+ _initialized = true;
// Setup mixer
syncSoundSettings();
@@ -106,9 +102,9 @@ LureEngine::~LureEngine() {
// Remove all of our debug levels here
DebugMan.clearAllDebugChannels();
- if (_initialised) {
- // Delete and deinitialise subsystems
- Surface::deinitialise();
+ if (_initialized) {
+ // Delete and deinitialize subsystems
+ Surface::deinitialize();
Sound.destroy();
delete _fights;
delete _room;
diff --git a/engines/lure/surface.cpp b/engines/lure/surface.cpp
index 783401fde2..bfada8fde6 100644
--- a/engines/lure/surface.cpp
+++ b/engines/lure/surface.cpp
@@ -18,9 +18,6 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
- * $URL$
- * $Id$
- *
*/
#include "lure/decode.h"
@@ -36,8 +33,8 @@
namespace Lure {
// These variables hold resources commonly used by the Surfaces, and must be initialised and freed
// by the static Surface methods initialise and deinitailse
static MemoryBlock *int_font = NULL;
static MemoryBlock *int_dialog_frame = NULL;
@@ -48,7 +45,7 @@ static const byte char8A[8] = {0x40, 0x20, 0x00, 0x90, 0x90, 0x90, 0x68, 0x00};
static const byte char8D[8] = {0x80, 0x40, 0x00, 0xc0, 0x40, 0x40, 0x60, 0x00}; // accented `i
static const byte char95[8] = {0x40, 0x20, 0x00, 0x60, 0x90, 0x90, 0x60, 0x00}; // accented `o
-void Surface::initialise() {
+void Surface::initialize() {
Disk &disk = Disk::getReference();
int_font = disk.getEntry(FONT_RESOURCE_ID);
int_dialog_frame = disk.getEntry(DIALOG_RESOURCE_ID);
@@ -83,7 +80,7 @@ void Surface::initialise() {
}
}
-void Surface::deinitialise() {
+void Surface::deinitialize() {
delete int_font;
delete int_dialog_frame;
}
@@ -36,8 +33,8 @@
namespace Lure {
-// These variables hold resources commonly used by the Surfaces, and must be initialised and freed
-// by the static Surface methods initialise and deinitailse
+// These variables hold resources commonly used by the Surfaces, and must be initialized and freed
+// by the static Surface methods initialize and deinitailse
static MemoryBlock *int_font = NULL;
static MemoryBlock *int_dialog_frame = NULL;